@@ -28,22 +28,22 @@ def _validate_ipv46_address(value: str) -> bool:
     return _validate_ipv4_address(value) or _validate_ipv6_address(value)
 
 
-def regex_check(address: EmailAddress) -> bool:
+def regex_check(email_address: EmailAddress) -> bool:
     'Slightly adjusted email regex checker from the Django project.'
 
     # Validate user part.
-    if not USER_REGEX.match(address.user):
+    if not USER_REGEX.match(email_address.user):
         raise AddressFormatError
 
     # Validate domain part.
-    if address.domain_literal_ip:
-        literal_match = LITERAL_REGEX.match(address.ace_domain)
+    if email_address.domain_literal_ip:
+        literal_match = LITERAL_REGEX.match(email_address.ace_domain)
         if literal_match is None:
             raise AddressFormatError
         if not _validate_ipv46_address(literal_match[1]):
             raise AddressFormatError
     else:
-        if HOST_REGEX.match(address.ace_domain) is None:
+        if HOST_REGEX.match(email_address.ace_domain) is None:
             raise AddressFormatError
 
     # All validations successful.
